@@ -15,6 +15,7 @@
 #include "pmem.h"
 #include "smbios.h"
 #include "smbus.h"
+#include "spd.h"
 #include "temperature.h"
 #include "tsc.h"
 
@@ -143,11 +144,14 @@ void display_init(void)
     clear_screen_region(ROW_FOOTER, 0, ROW_FOOTER, SCREEN_WIDTH - 1);
     prints(ROW_FOOTER, 0, " <ESC> Exit  <F1> Configuration  <Space> Scroll Lock");
     prints(ROW_FOOTER, 64, MT_VERSION "." GIT_HASH);
-#if TESTWORD_WIDTH > 32
-    prints(ROW_FOOTER, 76, ".x64");
-#else
-    prints(ROW_FOOTER, 76, ".x32");
+#if defined (__x86_64__)
+    prints(ROW_FOOTER, 74, ".x64");
+#elif defined (__i386__)
+    prints(ROW_FOOTER, 74, ".x32");
+#elif defined (__loongarch_lp64)
+    prints(ROW_FOOTER, 74, ".la64");
 #endif
+
     set_foreground_colour(WHITE);
     set_background_colour(BLUE);
 
@@ -265,7 +269,7 @@ void display_cpu_topology(void)
 void post_display_init(void)
 {
     print_smbios_startup_info();
-    print_smbus_startup_info();
+    print_spd_startup_info();
 
     if (imc.freq) {
         // Try to get RAM information from IMC
@@ -343,6 +347,14 @@ void display_start_test(void)
     display_test_description(test_list[test_num].description);
     test_bar_length = 0;
     test_ticks = 0;
+
+#if 0
+    uint64_t current_time = get_tsc();
+    int secs = (current_time - run_start_time) / (1000 * (uint64_t)clks_per_msec);
+    int mins  = secs / 60; secs %= 60;
+    int hours = mins / 60; mins %= 60;
+    do_trace(0, "T %i: %i:%02i:%02i", test_num, hours, mins, secs);
+#endif
 }
 
 void display_error_count(void)
