@@ -53,7 +53,7 @@ void *memmove(void *dest, const void *src, size_t n)
     return dest;
 }
 
-#ifdef DEBUG_GDB
+#if (defined(DEBUG_GDB) || defined(__loongarch_lp64))
 
 void *memcpy (void *dest, const void *src, size_t len)
 {
@@ -128,4 +128,4 @@ uint32_t hexstr2int(const char *hexstr) {
         ival = (ival << 4) | (b & 0xF);
     }
     return ival;
-}
\ No newline at end of file
+}
