@@ -36,7 +36,7 @@ static inline int memcmp(const void *s1, const void *s2, size_t n)
  * not overlap.
  * void *memcpy(void *dst, const void *src, size_t n);
  */
-#ifndef DEBUG_GDB
+#if !(defined(DEBUG_GDB) || defined(__loongarch_lp64))
     #define memcpy(d, s, n) __builtin_memcpy((d), (s), (n))
 #else
     void *memcpy (void *dest, const void *src, size_t len);
@@ -54,7 +54,7 @@ void *memmove(void *dest, const void *src, size_t n);
  * value c.
  * void *memset(void *s, int c, size_t n);
  */
-#ifndef DEBUG_GDB
+#if !(defined(DEBUG_GDB) || defined(__loongarch_lp64))
     #define memset(s, c, n) __builtin_memset((s), (c), (n))
 #else
     void *memset (void *dest, int val, size_t len);
