@@ -31,7 +31,7 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x000D, "Mostek" },
     { 0x000E, "Freescale" },
 //  { 0x000F, "National" },
-//  { 0x0010, "NEC" },
+    { 0x0010, "NEC" },
 //  { 0x0011, "RCA" },
 //  { 0x0012, "Raytheon" },
 //  { 0x0013, "Conexant (Rockwell)" },
@@ -111,7 +111,7 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x005D, "TECMAR" },
 //  { 0x005E, "Exar" },
 //  { 0x005F, "PCMCIA" },
-//  { 0x0060, "LG Semi (Goldstar)" },
+    { 0x0060, "LG" }, // LG Semi (Goldstar)
 //  { 0x0061, "Northern Telecom" },
     { 0x0062, "Sanyo" },
 //  { 0x0063, "Array Microsystems" },
@@ -205,7 +205,7 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x013D, "T Square" },
 //  { 0x013E, "Seiko Epson" },
 //  { 0x013F, "Broadcom" },
-//  { 0x0140, "Viking Components" },
+    { 0x0140, "Viking Components" },
 //  { 0x0141, "V3 Semiconductor" },
     { 0x0142, "Flextronics" },
 //  { 0x0143, "Suwa Electronics" },
@@ -853,6 +853,7 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x0650, "Silego Technology Inc" },
     { 0x0651, "Kinglife" },
 //  { 0x0652, "Ability Industries Ltd" },
+    { 0x0653, "Silicon Power" },
 //  { 0x0654, "Augusta Technology Inc" },
 //  { 0x0655, "Nantronics Semiconductors" },
 //  { 0x0656, "Hilscher Gesellschaft" },
@@ -898,7 +899,7 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x067E, "Triad Semiconductor Inc" },
 //  { 0x0701, "Siklu Communication Ltd" },
 //  { 0x0702, "A Force Manufacturing Ltd" },
-//  { 0x0703, "Strontium" },
+    { 0x0703, "Strontium" },
 //  { 0x0704, "ALi Corp (Abilis Systems)" },
 //  { 0x0705, "Siglead Inc" },
 //  { 0x0706, "Ubicom Inc" },
@@ -1676,5 +1677,6 @@ static const struct __attribute__((packed)) spd_jedec_manufacturer jep106[] = {
 //  { 0x0D1D, "Permanent Potential Limited" },
 //  { 0x0D1E, "Creative World International Limited" },
 //  { 0x0D1F, "Base Creation International Limited" },
+    { 0x0E51, "Xiaoli AI" },
     { 0xFFFF, "Unknown"}
 };
