@@ -2,11 +2,12 @@
 // Copyright (C) 2021-2022 Martin Whitaker.
 
 #include "keyboard.h"
-#include "memrw32.h"
+#include "memrw.h"
 #include "pci.h"
 #include "screen.h"
 #include "usb.h"
 #include "vmem.h"
+#include "hwquirks.h"
 
 #include "ehci.h"
 #include "ohci.h"
@@ -424,7 +425,7 @@ static void reset_usb_controller(hci_info_t *hci)
     uintptr_t mmio_size = pci_config_read32(bus, dev, func, bar);
     pci_config_write32(bus, dev, func, bar, base_addr);
     bool in_io_space = base_addr & 0x1;
-#ifdef __x86_64__
+#if (ARCH_BITS == 64)
     if (!in_io_space && (base_addr & 0x4)) {
         base_addr += (uintptr_t)pci_config_read32(bus, dev, func, bar + 4) << 32;
         pci_config_write32(bus, dev, func, bar + 4, 0xffffffff);
@@ -433,6 +434,14 @@ static void reset_usb_controller(hci_info_t *hci)
     } else {
         mmio_size += (uintptr_t)0xffffffff << 32;
     }
+#if defined(__loongarch_lp64)
+    base_addr |= (0xEULL << 40); // LoongArch64 64-bit PCI MMIO perfix
+
+    // Adjust Loongson7A2000 OHCI BAR offset.
+    if ((device_id == 0x7a24) && (pci_config_read8(bus, dev, func, 0x08) == 0x2)) {
+        base_addr += 0x1000;
+    }
+#endif
 #endif
     base_addr &= ~(uintptr_t)0xf;
     mmio_size &= ~(uintptr_t)0xf;
@@ -834,6 +843,10 @@ void find_usb_keyboards(bool pause_if_none)
 
     hci_info_t hci_list[MAX_HCI];
 
+    if ((quirk.type & QUIRK_TYPE_USB) && (quirk.process != NULL)) {
+        quirk.process();
+    }
+
     int num_hci = find_usb_controllers(hci_list);
 
     // Take ownership of all controllers and reset them.
